@@ -1,5 +1,5 @@
-use std::env;
 use std::collections::HashMap;
+use std::env;
 use std::process::{exit, Command, Output, Stdio};
 use std::str;
 
@@ -33,6 +33,11 @@ fn main() {
         }
     }
 
+    if binary.is_empty() {
+        println!("No binary given.");
+        exit(1);
+    }
+
     if aliases.contains_key(&binary) {
         binary = aliases.get(&binary).unwrap().to_string();
     }
